==> owncloud-8.2.11.tar.bz2: owncloud/apps/encryption/l10n/en_GB.js <==
OC.L10N.register(
    "encryption",
    {
    "Missing recovery key password" : "Missing recovery key password",
    "Please repeat the recovery key password" : "Please repeat the recovery key password",
    "Repeated recovery key password does not match the provided recovery key password" : "Repeated recovery key password does not match the provided recovery key password",
    "Recovery key successfully enabled" : "Recovery key enabled successfully",
    "Could not enable recovery key. Please check your recovery key password!" : "Could not enable recovery key. Please check your recovery key password!",
    "Recovery key successfully disabled" : "Recovery key disabled successfully",
    "Could not disable recovery key. Please check your recovery key password!" : "Could not disable recovery key. Please check your recovery key password!",
    "Missing parameters" : "Missing parameters",
    "Please provide the old recovery password" : "Please provide the old recovery password",
    "Please provide a new recovery password" : "Please provide a new recovery password",
    "Please repeat the new recovery password" : "Please repeat the new recovery password",
    "Password successfully changed." : "Password changed successfully.",
    "Could not change the password. Maybe the old password was not correct." : "Could not change the password. Maybe the old password was incorrect.",
    "Recovery Key disabled" : "Recovery Key disabled",
    "Recovery Key enabled" : "Recovery Key enabled",
    "Could not enable the recovery key, please try again or contact your administrator" : "Could not enable the recovery key, please try again or contact your administrator",
    "Could not update the private key password." : "Could not update the private key password.",
    "The old password was not correct, please try again." : "The old password was not correct, please try again.",
    "The current log-in password was not correct, please try again." : "The current log-in password was not correct, please try again.",
    "Private key password successfully updated." : "Private key password updated successfully.",
    "You need to migrate your encryption keys from the old encryption (ownCloud <= 8.0) to the new one. Please run 'occ encryption:migrate' or contact your administrator" : "You need to migrate your encryption keys from the old encryption (ownCloud <= 8.0) to the new one. Please run 'occ encryption:migrate' or contact your administrator",
    "Invalid private key for Encryption App. Please update your private key password in your personal settings to recover access to your encrypted files." : "Invalid private key for Encryption App. Please update your private key password in your personal settings to recover access to your encrypted files.",
    "Encryption App is enabled but your keys are not initialized, please log-out and log-in again" : "Encryption App is enabled but your keys are not initialised, please log-out and log-in again",
    "Encryption App is enabled and ready" : "Encryption App is enabled and ready",
    "Can not decrypt this file, probably this is a shared file. Please ask the file owner to reshare the file with you." : "Cannot decrypt this file, which is probably a shared file. Please ask the file owner to reshare the file with you.",
    "Can not read this file, probably this is a shared file. Please ask the file owner to reshare the file with you." : "Can not read this file, probably this is a shared file. Please ask the file owner to reshare the file with you.",
    "The share will expire on %s." : "The share will expire on %s.",
    "Cheers!" : "Cheers!",
    "Enable recovery key" : "Enable recovery key",
    "Disable recovery key" : "Disable recovery key",
    "The recovery key is an extra encryption key that is used to encrypt files. It allows recovery of a user's files if the user forgets his or her password." : "The recovery key is an extra encryption key that is used to encrypt files. It allows recovery of a user's files if the user forgets his or her password.",
    "Recovery key password" : "Recovery key password",
    "Repeat recovery key password" : "Repeat recovery key password",
    "Change recovery key password:" : "Change recovery key password:",
    "Old recovery key password" : "Old recovery key password",
    "New recovery key password" : "New recovery key password",
    "Repeat new recovery key password" : "Repeat new recovery key password",
    "Change Password" : "Change Password",
    "ownCloud basic encryption module" : "ownCloud basic encryption module",
    "Your private key password no longer matches your log-in password." : "Your private key password no longer matches your log-in password.",
    "Set your old private key password to your current log-in password:" : "Set your old private key password to your current log-in password:",
    " If you don't remember your old password you can ask your administrator to recover your files." : " If you don't remember your old password you can ask your administrator to recover your files.",
    "Old log-in password" : "Old login password",
    "Current log-in password" : "Current login password",
    "Update Private Key Password" : "Update Private Key Password",
    "Enable password recovery:" : "Enable password recovery:",
    "Enabling this option will allow you to reobtain access to your encrypted files in case of password loss" : "Enabling this option will allow you to reobtain access to your encrypted files in case of password loss",
    "Enabled" : "Enabled",
    "Disabled" : "Disabled"
},
"nplurals=2; plural=(n != 1);");

==> owncloud-10.16.0.tar.bz2: owncloud/apps/encryption/l10n/en_GB.js <==
OC.L10N.register(
    "encryption",
    {
    "Missing recovery key password" : "Missing recovery key password",
    "Please repeat the recovery key password" : "Please repeat the recovery key password",
    "Repeated recovery key password does not match the provided recovery key password" : "Repeated recovery key password does not match the provided recovery key password",
    "Recovery key successfully enabled" : "Recovery key enabled successfully",
    "Could not enable recovery key. Please check your recovery key password!" : "Could not enable recovery key. Please check your recovery key password!",
    "Recovery key successfully disabled" : "Recovery key disabled successfully",
    "Could not disable recovery key. Please check your recovery key password!" : "Could not disable recovery key. Please check your recovery key password!",
    "Missing parameters" : "Missing parameters",
    "Please provide the old recovery password" : "Please provide the old recovery password",
    "Please provide a new recovery password" : "Please provide a new recovery password",
    "Please repeat the new recovery password" : "Please repeat the new recovery password",
    "Password successfully changed." : "Password changed successfully.",
    "Could not change the password. Maybe the old password was not correct." : "Could not change the password. Maybe the old password was incorrect.",
    "Recovery Key disabled" : "Recovery Key disabled",
    "Recovery Key enabled" : "Recovery Key enabled",
    "Could not enable the recovery key, please try again or contact your administrator" : "Could not enable the recovery key, please try again or contact your administrator",
    "Could not update the private key password." : "Could not update the private key password.",
    "The old password was not correct, please try again." : "The old password was not correct, please try again.",
    "The current log-in password was not correct, please try again." : "The current log-in password was not correct, please try again.",
    "Private key password successfully updated." : "Private key password updated successfully.",
    "You need to migrate your encryption keys from the old encryption (ownCloud <= 8.0) to the new one. Please run 'occ encryption:migrate' or contact your administrator" : "You need to migrate your encryption keys from the old encryption (ownCloud <= 8.0) to the new one. Please run 'occ encryption:migrate' or contact your administrator",
    "Invalid private key for Encryption App. Please update your private key password in your personal settings to recover access to your encrypted files." : "Invalid private key for Encryption App. Please update your private key password in your personal settings to recover access to your encrypted files.",
    "Encryption App is enabled, but your keys are not initialized. Please log-out and log-in again." : "Encryption App is enabled, but your keys are not initialised. Please log-out and log-in again.",
    "Encryption App is enabled and ready" : "Encryption App is enabled and ready",
    "Bad Signature" : "Bad Signature",
    "Missing Signature" : "Missing Signature",
    "one-time password for server-side-encryption" : "one-time password for server-side-encryption",
    "Can not decrypt this file, probably this is a shared file. Please ask the file owner to reshare the file with you." : "Cannot decrypt this file, which is probably a shared file. Please ask the file owner to reshare the file with you.",
    "Can not read this file, probably this is a shared file. Please ask the file owner to reshare the file with you." : "Can not read this file, probably this is a shared file. Please ask the file owner to reshare the file with you.",
    "Hey there,\n\nthe admin enabled server-side-encryption. Your files were encrypted using the password '%s'.\n\nPlease login to the web interface, go to the section 'ownCloud basic encryption module' of your personal settings and update your encryption password by entering this password into the 'old log-in password' field and your current login-password.\n\n" : "Hey there,\n\nthe admin enabled server-side-encryption. Your files were encrypted using the password '%s'.\n\nPlease login to the web interface, go to the section 'ownCloud basic encryption module' of your personal settings and update your encryption password by entering this password into the 'old log-in password' field and your current login-password.\n\n",
    "The share will expire on %s." : "The share will expire on %s.",
    "Cheers!" : "Cheers!",
    "Hey there,<br><br>the admin enabled server-side-encryption. Your files were encrypted using the password <strong>%s</strong>.<br><br>Please login to the web interface, go to the section \"ownCloud basic encryption module\" of your personal settings and update your encryption password by entering this password into the \"old log-in password\" field and your current login-password.<br><br>" : "Hey there,<br><br>the admin enabled server-side-encryption. Your files were encrypted using the password <strong>%s</strong>.<br><br>Please login to the web interface, go to the section \"ownCloud basic encryption module\" of your personal settings and update your encryption password by entering this password into the \"old log-in password\" field and your current login-password.<br><br>",
    "Default encryption module" : "Default encryption module",
    "Encryption App is enabled but your keys are not initialized, please log-out and log-in again" : "Encryption App is enabled but your keys are not initialised, please log-out and log-in again",
    "Encryption type: Master Key" : "Encryption type: Master Key",
    "Encryption type: User Specific Key" : "Encryption type: User Specific Key",
    "Please select an encryption option" : "Please select an encryption option",
    "Master Key" : "Master Key",
    "Permanently select this mode" : "Permanently select this mode",
    "User Specific Key encryption module is deprecated. See the <a target=\"_blank\" rel=\"noreferrer\" href=\"%s\">server release notes ↗</a> for more information." : "User Specific Key encryption module is deprecated. See the <a target=\"_blank\" rel=\"noreferrer\" href=\"%s\">server release notes ↗</a> for more information.",
    "Encrypt the home storage" : "Encrypt the home storage",
    "Enabling this option encrypts all files stored on the main storage, otherwise only files on external storage will be encrypted" : "Enabling this option encrypts all files stored on the main storage, otherwise only files on external storage will be encrypted",
    "Enable recovery key" : "Enable recovery key",
    "Disable recovery key" : "Disable recovery key",
    "The recovery key is an extra encryption key that is used to encrypt files. It allows recovery of a user's files if the user forgets his or her password." : "The recovery key is an extra encryption key that is used to encrypt files. It allows recovery of a user's files if the user forgets his or her password.",
    "Recovery key password" : "Recovery key password",
    "Repeat recovery key password" : "Repeat recovery key password",
    "Change recovery key password:" : "Change recovery key password:",
    "Old recovery key password" : "Old recovery key password",
    "New recovery key password" : "New recovery key password",
    "Repeat new recovery key password" : "Repeat new recovery key password",
    "Change Password" : "Change Password",
    "ownCloud basic encryption module" : "ownCloud basic encryption module",
    "Your private key password no longer matches your log-in password." : "Your private key password no longer matches your log-in password.",
    "Set your old private key password to your current log-in password:" : "Set your old private key password to your current log-in password:",
    " If you don't remember your old password you can ask your administrator to recover your files." : " If you don't remember your old password you can ask your administrator to recover your files.",
    "Old log-in password" : "Old login password",
    "Current log-in password" : "Current login password",
    "Update Private Key Password" : "Update Private Key Password",
    "Enable password recovery:" : "Enable password recovery:",
    "Enabling this option will allow you to reobtain access to your encrypted files in case of password loss" : "Enabling this option will allow you to reobtain access to your encrypted files in case of password loss",
    "Enabled" : "Enabled",
    "Disabled" : "Disabled"
},
"nplurals=2; plural=(n != 1);");
